Index: code/branches/formationupdate/src/orxonox/controllers/FormationController.cc
===================================================================
--- code/branches/formationupdate/src/orxonox/controllers/FormationController.cc	(revision 9620)
+++ code/branches/formationupdate/src/orxonox/controllers/FormationController.cc	(revision 9621)
@@ -535,4 +535,5 @@
 
 
+    // Sets newMaster as the new master within the formation. Called by the master.
     void FormationController::setNewMasterWithinFormation(FormationController* newMaster)
         {
@@ -565,5 +566,5 @@
 
   /**
-        @brief Frees all slaves form a master. Initiated by a master.
+        @brief Frees all slaves from a master. Initiated by a master.
     */
     void FormationController::freeSlaves()
Index: code/branches/formationupdate/src/orxonox/controllers/FormationController.h
===================================================================
--- code/branches/formationupdate/src/orxonox/controllers/FormationController.h	(revision 9620)
+++ code/branches/formationupdate/src/orxonox/controllers/FormationController.h	(revision 9621)
@@ -59,5 +59,4 @@
       static void passivebehaviour(const bool passive);
       static void formationsize(const int size);
-      void setNewMasterWithinFormation();
       void setNewMasterWithinFormation(FormationController* newMaster);
 
@@ -100,7 +99,6 @@
       virtual void hit(Pawn* originator, btManifoldPoint& contactpoint, float damage);
 
-      /* Just for testing purposes: report the master. */
       FormationController* getMaster( void ) { return myMaster_; }
-      FormationController* getThis( void ) { return this; }
+      FormationController* getController( void ) { return this; }
       FormationController* getSlave( void ) { return this->slaves_.back(); }
 
@@ -136,4 +134,5 @@
       void takeLeadOfFormation();
       void loseMasterState();
+      void setNewMasterWithinFormation();
 
       void freeSlaves();
Index: code/branches/formationupdate/src/orxonox/worldentities/pawns/Pawn.cc
===================================================================
--- code/branches/formationupdate/src/orxonox/worldentities/pawns/Pawn.cc	(revision 9620)
+++ code/branches/formationupdate/src/orxonox/worldentities/pawns/Pawn.cc	(revision 9621)
@@ -309,7 +309,5 @@
 
 
-    /* Two functions to find the slaves of a Pawn
-     *
-     */
+    // A function to check if this pawn's controller is the master of any formationcontroller
     bool Pawn::hasSlaves()
     {
@@ -318,5 +316,5 @@
 			 it != ObjectList<FormationController>::end(); ++it )
 		{
 			// checks if the Pawn has a slave
 			if (this->hasHumanController() && it->getMaster() == this->getPlayer()->getController())
 				return true;
@@ -325,4 +323,5 @@
     }
 
+    // A function that returns a slave of the pawn's controller
     Controller* Pawn::getSlave(){
     	for (ObjectList<FormationController>::iterator it =
@@ -331,5 +330,5 @@
     	{
     		if (this->hasHumanController() && it->getMaster() == this->getPlayer()->getController())
-    			return it->getThis();
+    			return it->getController();
     	}
     	return 0;
@@ -353,6 +352,5 @@
             if (this->getPlayer() && this->getPlayer()->getControllableEntity() == this)
             {
-
-            	// Do different things if Pawn is the Master of a Formation
+            	// Start to control a new entity if you're the master of a formation
             	if(this->hasSlaves())
             	{
@@ -363,19 +361,9 @@
             		slave->setControllableEntity(0);
 
-
-            		// set new Master
+            		// set a new master within the formation
 					orxonox_cast<FormationController*>(this->getController())->setNewMasterWithinFormation(orxonox_cast<FormationController*>(slave));
-            		//orxonox_cast<FormationController*>(this->getController())->setNewMasterWithinFormation();
-
-
-            		/* TO DO: - setNewMasterWithinFormation() with an argument.
-            		 * 		  - set slave as the new master within the formation
-            		 *
-            		 */
 
 					// start to control a slave
     				this->getPlayer()->startControl(entity);
-
-
             	}
             	else
@@ -318,5 +316,5 @@
 			 it != ObjectList<FormationController>::end(); ++it )
 		{
-			// checks if the Pawn has a slave
+			// checks if the pawn's controller has a slave
 			if (this->hasHumanController() && it->getMaster() == this->getPlayer()->getController())
 				return true;
